@@ -5,7 +5,7 @@
 //!
 use {
     crate::{block_cost_limits::*, cost_model::TransactionCost},
-    solana_sdk::{clock::Slot, pubkey::Pubkey, transaction::Transaction},
+    solana_sdk::{clock::Slot, pubkey::Pubkey, transaction::SanitizedTransaction},
     std::collections::HashMap,
 };
 
@@ -55,22 +55,26 @@ impl CostTracker {
 
     pub fn would_transaction_fit(
         &self,
-        _transaction: &Transaction,
+        _transaction: &SanitizedTransaction,
         tx_cost: &TransactionCost,
     ) -> Result<(), CostTrackerError> {
         self.would_fit(&tx_cost.writable_accounts, &tx_cost.sum())
     }
 
-    pub fn add_transaction_cost(&mut self, _transaction: &Transaction, tx_cost: &TransactionCost) {
+    pub fn add_transaction_cost(
+        &mut self,
+        _transaction: &SanitizedTransaction,
+        tx_cost: &TransactionCost,
+    ) {
         self.add_transaction(&tx_cost.writable_accounts, &tx_cost.sum());
     }
 
     pub fn try_add(
         &mut self,
-        _transaction: &Transaction,
+        _transaction: &SanitizedTransaction,
         tx_cost: &TransactionCost,
     ) -> Result<u64, CostTrackerError> {
-        let cost = tx_cost.sum();
+        let cost = tx_cost.sum() * tx_cost.cost_weight as u64;
         self.would_fit(&tx_cost.writable_accounts, &cost)?;
         self.add_transaction(&tx_cost.writable_accounts, &cost);
         Ok(self.block_cost)
@@ -125,7 +129,7 @@ impl CostTracker {
 
         // check each account against account_cost_limit,
         for account_key in keys.iter() {
-            match self.cost_by_writable_accounts.get(&account_key) {
+            match self.cost_by_writable_accounts.get(account_key) {
                 Some(chained_cost) => {
                     if chained_cost + cost > self.account_cost_limit {
                         return Err(CostTrackerError::WouldExceedAccountMaxLimit);
@@ -176,7 +180,7 @@ mod tests {
             mint_keypair,
             ..
         } = create_genesis_config(10);
-        let bank = Arc::new(Bank::new_no_wallclock_throttle(&genesis_config));
+        let bank = Arc::new(Bank::new_no_wallclock_throttle_for_tests(&genesis_config));
         let start_hash = bank.last_blockhash();
         (mint_keypair, start_hash)
     }
@@ -187,7 +191,7 @@ mod tests {
     ) -> (Transaction, Vec<Pubkey>, u64) {
         let keypair = Keypair::new();
         let simple_transaction =
-            system_transaction::transfer(&mint_keypair, &keypair.pubkey(), 2, *start_hash);
+            system_transaction::transfer(mint_keypair, &keypair.pubkey(), 2, *start_hash);
 
         (simple_transaction, vec![mint_keypair.pubkey()], 5)
     }
@@ -301,6 +305,7 @@ mod tests {
     fn test_cost_tracker_try_add_is_atomic() {
         let (mint_keypair, start_hash) = test_setup();
         let (tx, _keys, _cost) = build_simple_transaction(&mint_keypair, &start_hash);
+        let tx = SanitizedTransaction::from_transaction_for_tests(tx);
 
         let acct1 = Pubkey::new_unique();
         let acct2 = Pubkey::new_unique();
@@ -368,4 +373,26 @@ mod tests {
             assert_eq!(acct2, costliest_account);
         }
     }
+
+    #[test]
+    fn test_try_add_with_cost_weight() {
+        let (mint_keypair, start_hash) = test_setup();
+        let (tx, _keys, _cost) = build_simple_transaction(&mint_keypair, &start_hash);
+        let tx = SanitizedTransaction::from_transaction_for_tests(tx);
+
+        let limit = 100u64;
+        let mut testee = CostTracker::new(limit, limit);
+
+        let mut cost = TransactionCost {
+            execution_cost: limit + 1,
+            ..TransactionCost::default()
+        };
+
+        // cost exceed limit by 1, will not fit
+        assert!(testee.try_add(&tx, &cost).is_err());
+
+        cost.cost_weight = 0u32;
+        // setting cost_weight to zero will allow this tx
+        assert!(testee.try_add(&tx, &cost).is_ok());
+    }
 }
