@@ -66,7 +66,7 @@ impl ExecuteCostTable {
                 .map(|(key, _)| key)
                 .expect("cannot find mode from cost table");
 
-            *self.table.get(&key).unwrap()
+            *self.table.get(key).unwrap()
         }
     }
 
@@ -74,7 +74,7 @@ impl ExecuteCostTable {
     // client is advised to call `get_average()` or `get_mode()` to
     // assign a 'default' value for new program.
     pub fn get_cost(&self, key: &Pubkey) -> Option<&u64> {
-        self.table.get(&key)
+        self.table.get(key)
     }
 
     pub fn upsert(&mut self, key: &Pubkey, value: u64) -> Option<u64> {
