@@ -6,6 +6,7 @@ pub mod accounts_cache;
 pub mod accounts_db;
 pub mod accounts_hash;
 pub mod accounts_index;
+pub mod accounts_index_storage;
 pub mod accounts_update_notifier_interface;
 pub mod ancestors;
 pub mod append_vec;
@@ -15,7 +16,12 @@ pub mod bank_forks;
 pub mod bank_utils;
 pub mod block_cost_limits;
 pub mod blockhash_queue;
+pub mod bloom;
+pub mod bucket_map_holder;
+pub mod bucket_map_holder_stats;
 pub mod builtins;
+pub mod cache_hash_data;
+pub mod cache_hash_data_stats;
 pub mod commitment;
 pub mod contains;
 pub mod cost_model;
@@ -24,24 +30,26 @@ pub mod epoch_stakes;
 pub mod execute_cost_table;
 pub mod genesis_utils;
 pub mod hardened_unpack;
-pub mod hashed_transaction;
-pub mod inline_spl_associated_token_account;
+pub mod in_mem_accounts_index;
 pub mod inline_spl_token;
-pub mod instruction_recorder;
 pub mod loader_utils;
-pub mod log_collector;
 pub mod message_processor;
-mod native_loader;
-pub mod neon_evm_program;
 pub mod non_circulating_supply;
+mod nonce_keyed_account;
 mod pubkey_bins;
 mod read_only_accounts_cache;
 pub mod rent_collector;
 pub mod secondary_index;
 pub mod serde_snapshot;
+mod shared_buffer_reader;
+pub mod snapshot_archive_info;
+pub mod snapshot_config;
+pub mod snapshot_hash;
 pub mod snapshot_package;
 pub mod snapshot_utils;
 pub mod sorted_storages;
+pub mod stake_delegations;
+pub mod stake_history;
 pub mod stake_weighted_timestamp;
 pub mod stakes;
 pub mod status_cache;
@@ -49,6 +57,7 @@ mod system_instruction_processor;
 pub mod transaction_batch;
 pub mod vote_account;
 pub mod vote_sender_types;
+pub mod waitable_condvar;
 
 #[macro_use]
 extern crate solana_metrics;
