@@ -8,17 +8,18 @@ use {
             TransactionAccountRefCell,
         },
         log_collector::LogCollector,
-        timings::ExecuteDetailsTimings,
+        timings::ExecuteTimings,
     },
     solana_sdk::{
         account::WritableAccount,
         compute_budget::ComputeBudget,
         feature_set::{prevent_calling_precompiles_as_programs, FeatureSet},
         hash::Hash,
-        message::Message,
+        message::SanitizedMessage,
         precompiles::is_precompile,
         pubkey::Pubkey,
         rent::Rent,
+        saturating_add_assign,
         sysvar::instructions,
         transaction::TransactionError,
     },
@@ -40,8 +41,8 @@ impl ::solana_frozen_abi::abi_example::AbiExample for MessageProcessor {
 /// Resultant information gathered from calling process_message()
 #[derive(Debug, Default, Clone, Copy, PartialEq, Eq)]
 pub struct ProcessedMessageInfo {
-    /// The amount that the accounts data len has changed
-    pub accounts_data_len_delta: i64,
+    /// The new accounts data len
+    pub accounts_data_len: u64,
 }
 
 impl MessageProcessor {
@@ -53,7 +54,7 @@ impl MessageProcessor {
     #[allow(clippy::too_many_arguments)]
     pub fn process_message(
         builtin_programs: &[BuiltinProgram],
-        message: &Message,
+        message: &SanitizedMessage,
         program_indices: &[Vec<usize>],
         accounts: &[TransactionAccountRefCell],
         rent: Rent,
@@ -62,10 +63,11 @@ impl MessageProcessor {
         instruction_recorders: Option<&[InstructionRecorder]>,
         feature_set: Arc<FeatureSet>,
         compute_budget: ComputeBudget,
-        timings: &mut ExecuteDetailsTimings,
+        timings: &mut ExecuteTimings,
         sysvars: &[(Pubkey, Vec<u8>)],
         blockhash: Hash,
         lamports_per_signature: u64,
+        current_accounts_data_len: u64,
     ) -> Result<ProcessedMessageInfo, TransactionError> {
         let mut invoke_context = InvokeContext::new(
             rent,
@@ -78,16 +80,15 @@ impl MessageProcessor {
             feature_set,
             blockhash,
             lamports_per_signature,
+            current_accounts_data_len,
         );
 
-        debug_assert_eq!(program_indices.len(), message.instructions.len());
-        for (instruction_index, (instruction, program_indices)) in message
-            .instructions
-            .iter()
+        debug_assert_eq!(program_indices.len(), message.instructions().len());
+        for (instruction_index, ((program_id, instruction), program_indices)) in message
+            .program_instructions_iter()
             .zip(program_indices.iter())
             .enumerate()
         {
-            let program_id = instruction.program_id(&message.account_keys);
             if invoke_context
                 .feature_set
                 .is_active(&prevent_calling_precompiles_as_programs::id())
@@ -99,7 +100,7 @@ impl MessageProcessor {
 
             // Fixup the special instructions key if present
             // before the account pre-values are taken care of
-            for (pubkey, account) in accounts.iter().take(message.account_keys.len()) {
+            for (pubkey, account) in accounts.iter().take(message.account_keys_len()) {
                 if instructions::check_id(pubkey) {
                     let mut mut_account_ref = account.borrow_mut();
                     instructions::store_current_index(
@@ -118,19 +119,32 @@ impl MessageProcessor {
             let ProcessInstructionResult {
                 compute_units_consumed,
                 result,
-            } = invoke_context.process_instruction(message, instruction, program_indices, &[], &[]);
+            } = invoke_context.process_instruction(
+                message,
+                instruction,
+                program_indices,
+                &[],
+                &[],
+                timings,
+            );
             time.stop();
-            timings.accumulate_program(
-                instruction.program_id(&message.account_keys),
+            timings.details.accumulate_program(
+                program_id,
                 time.as_us(),
                 compute_units_consumed,
                 result.is_err(),
             );
-            timings.accumulate(&invoke_context.timings);
+            timings.details.accumulate(&invoke_context.timings);
+            saturating_add_assign!(
+                timings.execute_accessories.process_instructions.total_us,
+                time.as_us()
+            );
             result
                 .map_err(|err| TransactionError::InstructionError(instruction_index as u8, err))?;
         }
-        Ok(ProcessedMessageInfo::default())
+        Ok(ProcessedMessageInfo {
+            accounts_data_len: invoke_context.get_accounts_data_meter().current(),
+        })
     }
 }
 
@@ -231,14 +245,14 @@ mod tests {
             AccountMeta::new(accounts[0].0, true),
             AccountMeta::new_readonly(accounts[1].0, false),
         ];
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_system_program_id,
                 &MockSystemInstruction::Correct,
                 account_metas.clone(),
             )],
             Some(&accounts[0].0),
-        );
+        ));
 
         let result = MessageProcessor::process_message(
             builtin_programs,
@@ -251,23 +265,24 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert!(result.is_ok());
         assert_eq!(accounts[0].1.borrow().lamports(), 100);
         assert_eq!(accounts[1].1.borrow().lamports(), 0);
 
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_system_program_id,
                 &MockSystemInstruction::AttemptCredit { lamports: 50 },
                 account_metas.clone(),
             )],
             Some(&accounts[0].0),
-        );
+        ));
 
         let result = MessageProcessor::process_message(
             builtin_programs,
@@ -280,10 +295,11 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert_eq!(
             result,
@@ -293,14 +309,14 @@ mod tests {
             ))
         );
 
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_system_program_id,
                 &MockSystemInstruction::AttemptDataChange { data: 50 },
                 account_metas,
             )],
             Some(&accounts[0].0),
-        );
+        ));
 
         let result = MessageProcessor::process_message(
             builtin_programs,
@@ -313,10 +329,11 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert_eq!(
             result,
@@ -438,14 +455,14 @@ mod tests {
         ];
 
         // Try to borrow mut the same account
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_program_id,
                 &MockSystemInstruction::BorrowFail,
                 account_metas.clone(),
             )],
             Some(&accounts[0].0),
-        );
+        ));
         let result = MessageProcessor::process_message(
             builtin_programs,
             &message,
@@ -457,10 +474,11 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert_eq!(
             result,
@@ -471,14 +489,14 @@ mod tests {
         );
 
         // Try to borrow mut the same account in a safe way
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_program_id,
                 &MockSystemInstruction::MultiBorrowMut,
                 account_metas.clone(),
             )],
             Some(&accounts[0].0),
-        );
+        ));
         let result = MessageProcessor::process_message(
             builtin_programs,
             &message,
@@ -490,15 +508,16 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert!(result.is_ok());
 
         // Do work on the same account but at different location in keyed_accounts[]
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[Instruction::new_with_bincode(
                 mock_program_id,
                 &MockSystemInstruction::DoWork {
@@ -508,7 +527,7 @@ mod tests {
                 account_metas,
             )],
             Some(&accounts[0].0),
-        );
+        ));
         let result = MessageProcessor::process_message(
             builtin_programs,
             &message,
@@ -520,10 +539,11 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert!(result.is_ok());
         assert_eq!(accounts[0].1.borrow().lamports(), 80);
@@ -555,7 +575,7 @@ mod tests {
             (mock_program_id, mock_program_account),
         ];
 
-        let message = Message::new(
+        let message = SanitizedMessage::Legacy(Message::new(
             &[
                 new_secp256k1_instruction(
                     &libsecp256k1::SecretKey::random(&mut rand::thread_rng()),
@@ -564,7 +584,7 @@ mod tests {
                 Instruction::new_with_bytes(mock_program_id, &[], vec![]),
             ],
             None,
-        );
+        ));
 
         let result = MessageProcessor::process_message(
             builtin_programs,
@@ -577,10 +597,11 @@ mod tests {
             None,
             Arc::new(FeatureSet::all_enabled()),
             ComputeBudget::new(),
-            &mut ExecuteDetailsTimings::default(),
+            &mut ExecuteTimings::default(),
             &[],
             Hash::default(),
             0,
+            0,
         );
         assert_eq!(
             result,
