@@ -1,13 +1,13 @@
 //! ReadOnlyAccountsCache used to store accounts, such as executable accounts,
 //! which can be large, loaded many times, and rarely change.
 //use mapref::entry::{Entry, OccupiedEntry, VacantEntry};
-use solana_sdk::{
-    account::{AccountSharedData, ReadableAccount},
-    clock::Slot,
-    pubkey::Pubkey,
-};
 use {
     dashmap::{mapref::entry::Entry, DashMap},
+    solana_sdk::{
+        account::{AccountSharedData, ReadableAccount},
+        clock::Slot,
+        pubkey::Pubkey,
+    },
     std::{
         sync::{
             atomic::{AtomicBool, AtomicU64, AtomicUsize, Ordering},
